==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'F&#337;oldal',
'articles' => 'Cikkek',
'articles_auteur' => 'E szerz&#337; cikkei',
'articles_populaires' => 'Legn&eacute;pszer&#369;bb cikkek',
'articles_rubrique' => 'A rovat cikkei',
'aucun_article' => '<NENincs cikke ezen a c&iacute;men',
'aucun_auteur' => 'Nincs szerz&#337; ezen a c&iacute;men',
'aucun_site' => 'Nincs honlap ezen a c&iacute;men',
'aucune_breve' => 'Nincs h&iacute;r ezen a c&iacute;men',
'aucune_rubrique' => 'Nincs rovat ezen a c&iacute;men',
'autres_breves' => 'Egy&eacute;b h&iacute;rek',
'autres_groupes_mots_clefs' => 'Egy&eacute;b kulcssz&oacute; csoportok',
'autres_sites' => 'Egy&eacute;b honlapok',

// B
'bonjour' => 'J&oacute; napot',
'breves' => 'H&iacute;rek',

// C
'commenter_site' => 'Hozz&aacute;sz&oacute;l&aacute;s a honlapr&oacute;l',

// D
'date' => 'D&aacute;tum',
'dernier_ajout' => 'Utols&oacute; besz&uacute;r&aacute;s',
'dernieres_breves' => 'Utols&oacute; h&iacute;rek',
'derniers_articles' => 'Utols&oacute; cikkek',
'derniers_commentaires' => 'Utols&oacute; hozz&aacute;sz&oacute;l&aacute;sok',
'derniers_messages_forum' => 'A f&oacute;rumokba k&uuml;ld&ouml;tt legutols&oacute; &uuml;zenetek',

// E
'edition_mode_texte' => 'Sz&ouml;veges m&oacute;dban szerkeszt&eacute;s',
'en_reponse' => 'Erre v&aacute;laszolva&nbsp;:',
'en_resume' => '&Ouml;sszefoglalva',
'envoyer_message' => '&Uuml;zenet k&uuml;ld&eacute;s',
'espace_prive' => 'Priv&aacute;t r&eacute;sz',

// F
'forum' => 'F&oacute;rum',

// H
'hierarchie_site' => 'A honlap fel&eacute;p&iacute;t&eacute;se',

// J
'jours' => 'napok',

// M
'meme_auteur' => 'Ugyanett&#337;l a szerz&#337;t&#337;l',
'meme_rubrique' => 'Ugyanabban a rovatban',
'memes_auteurs' => 'Ugyanett&#337;l a szerz&#337;kt&#337;l',
'message' => '&Uuml;zenet',
'messages_forum' => 'F&oacute;rum &uuml;zenetei',
'messages_recents' => 'A f&oacute;rumok legfr&iacute;ssebb &uuml;zenetei',
'mots_clefs' => 'Kulcsszavak',
'mots_clefs_meme_groupe' => 'Kulcsszavak ugyanabban a csoportban',

// N
'navigation' => 'B&ouml;ng&eacute;sz&eacute;s',
'nom' => 'N&eacute;v',
'nouveautes' => '&Uacute;jdons&aacute;gok',
'nouveautes_web' => '&Uacute;jdons&aacute;gok a Weben',
'nouveaux_articles' => '&Uacute;j cikkek',
'nouvelles_breves' => '&Uacute;j h&iacute;rek',

// P
'page_precedente' => 'El&ouml;z&#337; oldal',
'page_suivante' => 'k&ouml;vetkez&#337; oldal',
'par_auteur' => '&iacute;rta',
'participer_site' => 'R&eacute;szt vehet a honlap &eacute;let&eacute;ben, &eacute;s saj&aacute;t cikkeket k&uuml;ldhet. Az&eacute;rt egy beiratkoz&aacute;s sz&uuml;ks&eacute;ges (l&aacute;sd lejjebb). Azonnal fog kapni egy emailt, melyben szerepelnek a hozz&aacute;f&eacute;r&eacute;si param&eacute;terek a honlap priv&aacute;t r&eacute;sz&eacute;re.',
'plan_site' => 'Honlap t&eacute;rk&eacute;pe',
'popularite' => 'N&eacute;pszer&#369;s&eacute;g',
'poster_message' => '&Uuml;zenet k&uuml;ld&eacute;s',
'proposer_site' => 'Honlapot aj&aacute;nlhat abban a rovatban&nbsp;:',

// R
'repondre_article' => 'Hozz&aacute;sz&oacute;l&aacute;s a cikkhez',
'repondre_breve' => 'V&aacute;laszolni erre a h&iacute;rre',
'repondre_message' => 'V&aacute;laszolni erre az &uuml;zenetre',
'resultats_recherche' => 'Keres&eacute;s eredm&eacute;nyei',
'retour_debut_forums' => 'Vissza a f&oacute;rumok kezdet&eacute;re',
'rubrique' => 'Rovat',
'rubriques' => 'Rovatok',

// S
'signatures_petition' => 'Al&aacute;&iacute;r&aacute;sok',
'site_realise_avec_spip' => 'A honlap SPIP seg&iacute;ts&eacute;g&eacute;vel k&eacute;sz&uuml;lt',
'sites_web' => 'Honlapok',
'sous_rubriques' => 'Als&oacute;bb rovatok',
'suite' => 'folytat&aacute;s',
'sur_web' => 'Valahol a Weben',
'syndiquer_rubrique' => 'A rovat szindik&aacute;l&aacute;sa',
'syndiquer_site' => 'Az eg&eacute;sz honlap szindik&aacute;l&aacute;sa',

// T
'texte_lettre_information' => '&Iacute;me a honlap h&iacute;rlevele',
'texte_lettre_information_2' => 'Ez a h&iacute;rlev&eacute;l a cikkeket, ill. h&iacute;reket &ouml;sszefoglalja az&oacute;ta',

// V
'ver_imprimer' => 'Nyomtathat&oacute; v&aacute;ltozat',
'voir_en_ligne' => 'L&aacute;tni &eacute;l&#337;ben',
'voir_squelette' => '<NEW>t&eacute;l&eacute;charger le squelette de cette page'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'F&#337;oldal',
'article' => 'Article', # NEW
'articles' => 'Cikkek',
'articles_auteur' => 'E szerz&#337; cikkei',
'articles_populaires' => 'Legn&eacute;pszer&#369;bb cikkek',
'articles_rubrique' => 'A rovat cikkei',
'aucun_article' => '<NENincs cikke ezen a c&iacute;men',
'aucun_auteur' => 'Nincs szerz&#337; ezen a c&iacute;men',
'aucun_site' => 'Nincs honlap ezen a c&iacute;men',
'aucune_breve' => 'Nincs h&iacute;r ezen a c&iacute;men',
'aucune_rubrique' => 'Nincs rovat ezen a c&iacute;men',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Egy&eacute;b h&iacute;rek',
'autres_groupes_mots_clefs' => 'Egy&eacute;b kulcssz&oacute; csoportok',
'autres_sites' => 'Egy&eacute;b honlapok',

// B
'bonjour' => 'J&oacute; napot',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'H&iacute;rek',

// C
'commenter_site' => 'Hozz&aacute;sz&oacute;l&aacute;s a honlapr&oacute;l',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'D&aacute;tum',
'dernier_ajout' => 'Utols&oacute; besz&uacute;r&aacute;s',
'dernieres_breves' => 'Utols&oacute; h&iacute;rek',
'derniers_articles' => 'Utols&oacute; cikkek',
'derniers_commentaires' => 'Utols&oacute; hozz&aacute;sz&oacute;l&aacute;sok',
'derniers_messages_forum' => 'A f&oacute;rumokba k&uuml;ld&ouml;tt legutols&oacute; &uuml;zenetek',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Sz&ouml;veges m&oacute;dban szerkeszt&eacute;s',
'en_reponse' => 'Erre v&aacute;laszolva&nbsp;:',
'en_resume' => '&Ouml;sszefoglalva',
'envoyer_message' => '&Uuml;zenet k&uuml;ld&eacute;s',
'espace_prive' => 'Priv&aacute;t r&eacute;sz',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'F&oacute;rum',

// H
'hierarchie_site' => 'A honlap fel&eacute;p&iacute;t&eacute;se',

// J
'jours' => 'napok',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Ugyanett&#337;l a szerz&#337;t&#337;l',
'meme_rubrique' => 'Ugyanabban a rovatban',
'memes_auteurs' => 'Ugyanett&#337;l a szerz&#337;kt&#337;l',
'message' => '&Uuml;zenet',
'messages_forum' => 'F&oacute;rum &uuml;zenetei',
'messages_recents' => 'A f&oacute;rumok legfr&iacute;ssebb &uuml;zenetei',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Kulcsszavak',
'mots_clefs_meme_groupe' => 'Kulcsszavak ugyanabban a csoportban',

// N
'navigation' => 'B&ouml;ng&eacute;sz&eacute;s',
'nom' => 'N&eacute;v',
'nouveautes' => '&Uacute;jdons&aacute;gok',
'nouveautes_web' => '&Uacute;jdons&aacute;gok a Weben',
'nouveaux_articles' => '&Uacute;j cikkek',
'nouvelles_breves' => '&Uacute;j h&iacute;rek',

// P
'page_precedente' => 'El&ouml;z&#337; oldal',
'page_suivante' => 'k&ouml;vetkez&#337; oldal',
'par_auteur' => '&iacute;rta',
'participer_site' => 'R&eacute;szt vehet a honlap &eacute;let&eacute;ben, &eacute;s saj&aacute;t cikkeket k&uuml;ldhet. Az&eacute;rt egy beiratkoz&aacute;s sz&uuml;ks&eacute;ges (l&aacute;sd lejjebb). Azonnal fog kapni egy emailt, melyben szerepelnek a hozz&aacute;f&eacute;r&eacute;si param&eacute;terek a honlap priv&aacute;t r&eacute;sz&eacute;re.',
'plan_site' => 'Honlap t&eacute;rk&eacute;pe',
'popularite' => 'N&eacute;pszer&#369;s&eacute;g',
'poster_message' => '&Uuml;zenet k&uuml;ld&eacute;s',
'proposer_site' => 'Honlapot aj&aacute;nlhat abban a rovatban&nbsp;:',

// R
'repondre_article' => 'Hozz&aacute;sz&oacute;l&aacute;s a cikkhez',
'repondre_breve' => 'V&aacute;laszolni erre a h&iacute;rre',
'repondre_message' => 'V&aacute;laszolni erre az &uuml;zenetre',
'resultats_recherche' => 'Keres&eacute;s eredm&eacute;nyei',
'retour_debut_forums' => 'Vissza a f&oacute;rumok kezdet&eacute;re',
'rubrique' => 'Rovat',
'rubriques' => 'Rovatok',

// S
'signatures_petition' => 'Al&aacute;&iacute;r&aacute;sok',
'site_realise_avec_spip' => 'A honlap SPIP seg&iacute;ts&eacute;g&eacute;vel k&eacute;sz&uuml;lt',
'sites_web' => 'Honlapok',
'sous_rubriques' => 'Als&oacute;bb rovatok',
'spam' => 'Spam', # NEW
'suite' => 'folytat&aacute;s',
'sur_web' => 'Valahol a Weben',
'syndiquer_rubrique' => 'A rovat szindik&aacute;l&aacute;sa',
'syndiquer_site' => 'Az eg&eacute;sz honlap szindik&aacute;l&aacute;sa',

// T
'texte_lettre_information' => '&Iacute;me a honlap h&iacute;rlevele',
'texte_lettre_information_2' => 'Ez a h&iacute;rlev&eacute;l a cikkeket, ill. h&iacute;reket &ouml;sszefoglalja az&oacute;ta',

// V
'ver_imprimer' => 'Nyomtathat&oacute; v&aacute;ltozat',
'voir_en_ligne' => 'L&aacute;tni &eacute;l&#337;ben',
'voir_squelette' => 't&eacute;l&eacute;charger le squelette de cette page', # NE
);

?>
